@@ -522,8 +522,9 @@ class Shell(object):
                     kind = "gitbash"
             kind = kind.lower()
             if kind == "gitbash":
-                subprocess.Popen([r"C:\Program Files\Git\git-bash.exe",
+                p = subprocess.Popen([r"C:\Program Files\Git\git-bash.exe",
                                   "-c", f"{command}"])
+                return p.pid
             elif kind == "cmd":
                 Console.error(f"Command not implemented for {kind}")
             elif kind == "powershell":
@@ -1019,8 +1020,12 @@ class Shell(object):
         :param what:
         :return:
         """
+        if type(lines) == str:
+            _lines = lines.splitlines()
+        else:
+            _lines = lines
         result = []
-        for line in lines:
+        for line in _lines:
             if what in line:
                 result.append(line)
         return result
@@ -1033,8 +1038,12 @@ class Shell(object):
         :param what:
         :return:
         """
+        if type(lines) == str:
+            _lines = lines.splitlines()
+        else:
+            _lines = lines
         result = []
-        for line in lines:
+        for line in _lines:
             if what not in line:
                 result = result + [line]
         return result
@@ -1047,8 +1056,12 @@ class Shell(object):
         :param what:
         :return:
         """
+        if type(lines) == str:
+            _lines = lines.splitlines()
+        else:
+            _lines = lines
         result = []
-        for line in lines:
+        for line in _lines:
             if what in line:
                 result = result + [line]
         return result
@@ -1061,9 +1074,13 @@ class Shell(object):
         :param what:
         :return:
         """
+        if type(lines) == str:
+            _lines = lines.splitlines()
+        else:
+            _lines = lines
         result = []
         found = False
-        for line in lines:
+        for line in _lines:
             found = found or what in line
             if found:
                 result = result + [line]
@@ -1089,9 +1106,13 @@ class Shell(object):
         :param what:
         :return:
         """
+        if type(lines) == str:
+            _lines = lines.splitlines()
+        else:
+            _lines = lines
         result = []
         found = True
-        for line in lines:
+        for line in _lines:
             if what in line:
                 return result
             else:
@@ -1112,7 +1133,7 @@ class Shell(object):
             kind = 'darwin'
         elif 'cygwin' in what:
             kind = 'cygwin'
-        elif 'windows' in what:
+        elif what in ['windows', 'win32']:
             kind = 'windows'
 
         return kind
@@ -1214,9 +1235,11 @@ class Shell(object):
         :return:
         """
         directory = path_expand(directory)
-        try:
-            os.makedirs(directory)
-        except OSError as e:
+        Path(directory).mkdir(parents=True, exist_ok=True)
+
+        #try:
+        #    os.makedirs(directory)
+        #except OSError as e:
 
             # EEXIST (errno 17) occurs under two conditions when the path exists:
             # - it is a file
@@ -1224,10 +1247,10 @@ class Shell(object):
             #
             # if it is a file, this is a valid error, otherwise, all
             # is fine.
-            if e.errno == errno.EEXIST and os.path.isdir(directory):
-                pass
-            else:
-                raise
+        #    if e.errno == errno.EEXIST and os.path.isdir(directory):
+        #        pass
+        #    else:
+        #        raise
 
     def unzip(cls, source_filename, dest_dir):
         """
