@@ -21,13 +21,66 @@ pprint(StopWatch.get_benchmark(user=user, node=node))
 
 StopWatch.benchmark(user=user, node=node)
 
+## Context Block
+
+StoWatch alos comes with a context block allowing to use the convenient with statement. However thi sis only recommended
+when the block is small as it is easy to lose the indentation in larger code. You can also certainly split the code up in
+functions so it is easier managable.
+
+Here is a simple example on how to use the with statement, showing that is can be used for streams and files.
+The mode tetermins if the file will be recreated, or if it will be appanded on. In addition there is the ability to
+write metadata into the record with a dict that can optionally be passed along.
+
+    from cloudmesh.common.StopWatch import StopWatchBlock
+    from cloudmesh.common.StopWatch import StopWatch
+    from cloudmesh.common.util import readfile
+
+    import time
+
+    data = {"step": "value"}
+
+    StopWatch.event("event-start")
+
+    with StopWatchBlock("total"):
+        time.sleep(1.0)
+
+    with StopWatchBlock("dict", data=data):
+        time.sleep(1.0)
+        data["step"] = 1
+
+    with StopWatchBlock("file", data=data, log="a.log", mode="w"):
+        time.sleep(1.0)
+        data["step"] = 2
+
+    with StopWatchBlock("append", data=data, log="a.log", mode="a"):
+        time.sleep(1.0)
+        data["step"] = 3
+
+    content = readfile ("a.log")
+    print (79*"=")
+    print (content.strip())
+    print (79*"=")
+
+
+    StopWatch.event("event-stop")
+
+    StopWatch.benchmark(sysinfo=False, user="gregor", node="computer",
+                        attributes=["timer", "status", "time", "start"]
+)
+
+
+
 """
 import os
 import time
+import datetime
 from pprint import pprint
+import sys
 
 from cloudmesh.common.Tabulate import Printer
 from cloudmesh.common.systeminfo import systeminfo as cm_systeminfo
+from time import perf_counter
+
 
 def rename(newname):
     """
@@ -37,11 +90,14 @@ def rename(newname):
     :return: renamed function
     :rtype: object
     """
+
     def decorator(f):
         f.__name__ = newname
         return f
+
     return decorator
 
+
 def benchmark(func):
     """
     decorator to benchmark a function
@@ -50,11 +106,13 @@ def benchmark(func):
     :return: function with benchmarks based on the name of the function
     :rtype: object
     """
+
     @rename(func.__name__)
     def wrapper(*args, **kwargs):
         StopWatch.start(func.__name__)
         func(*args, **kwargs)
         StopWatch.stop(func.__name__)
+
     return wrapper
 
 class StopWatch(object):
@@ -120,6 +178,17 @@ class StopWatch(object):
         """
         cls.timer_msg[name] = value
 
+    @classmethod
+    def event(cls, name):
+        """
+        adds an event with a given name, where start and stop is the same tme.
+
+        :param name: the name of the timer
+        :type name: string
+        """
+        StopWatch.start(name)
+        StopWatch.stop(name)
+        StopWatch.timer_end[name] = StopWatch.timer_start[name]
 
     @classmethod
     def start(cls, name):
@@ -234,6 +303,15 @@ class StopWatch(object):
             else:
                 raise Exception("StopWatch: wrong number of arguments")
 
+    @classmethod
+    def output(cls, name):
+        """
+        prints a timer. The first argument is the label if it exists, the last is the timer
+        :param args: label, name
+        :return:
+        """
+        print(name, str("{0:.2f}".format(cls.get(name))), "s")
+
     @classmethod
     def __str__(cls):
         """
@@ -272,7 +350,6 @@ class StopWatch(object):
             output="table"
         )
 
-
     @classmethod
     def get_sysinfo(cls,
                     node=None,
@@ -280,15 +357,14 @@ class StopWatch(object):
         data_platform = cm_systeminfo(node=node, user=user)
         return data_platform
 
-
     @classmethod
     def get_benchmark(cls,
-                  sysinfo=True,
-                  tag=None,
-                  node=None,
-                  user=None,
-                  total=False,
-                ):
+                      sysinfo=True,
+                      tag=None,
+                      node=None,
+                      user=None,
+                      total=False,
+                      ):
         """
         prints out all timers in a convenient benchmark table
 
@@ -341,8 +417,8 @@ class StopWatch(object):
                                            time.gmtime(
                                                StopWatch.timer_start[timer])),
                     'stop': time.strftime("%Y-%m-%d %H:%M:%S",
-                                           time.gmtime(
-                                               StopWatch.timer_end[timer])),
+                                          time.gmtime(
+                                              StopWatch.timer_end[timer])),
                     'time': StopWatch.get(timer, digits=3),
                     'sum': StopWatch.sum(timer, digits=3),
                     'status': StopWatch.get_status(timer),
@@ -352,8 +428,6 @@ class StopWatch(object):
                 }
                 total_time = total_time + StopWatch.get(timer)
 
-
-
             # print(Printer.attribute(data_timers, header=["Command", "Time/s"]))
 
             if 'benchmark_start_stop' in data_timers:
@@ -368,7 +442,6 @@ class StopWatch(object):
             if total:
                 print("Total:", total_time)
 
-
             benchmark_data["benchmark"] = data_timers
 
         else:
@@ -460,7 +533,6 @@ class StopWatch(object):
                     else:
                         data_timers[timer][attribute] = data_platform[attribute]
 
-
             # print(Printer.attribute(data_timers, header=["Command", "Time/s"]))
 
             if 'benchmark_start_stop' in data_timers:
@@ -512,6 +584,9 @@ class StopWatch(object):
                     "Status",
                     "Time"
                 ]
+            else:
+                order = attributes
+                header = attributes
             print()
             print(Printer.write(
                 data_timers,
@@ -550,3 +625,85 @@ class StopWatch(object):
         else:
 
             print("ERROR: No timers found")
+
+    def load(filename,
+             label=["name"], label_split_char=" ",
+             attributes=['timer',
+                         'status',
+                         'time',
+                         'sum',
+                         'start',
+                         'tag',
+                         'msg',
+                         'uname.node',
+                         'user',
+                         'uname.system',
+                         'platform.version']):
+        """
+        Loads data written to a file from the #csv lines.
+        If the timer name has spaces in it, it must also have a label tag in which each lable is the name when
+        splitting up the timer name. The list of attributes is the list specified plus the once generated from the
+        timer name by splitting.
+
+        Example:
+            data = StopWatch.load(logfile, label=["name", "n"], attributes=["timer", "time", "user", "uname.node"])
+
+
+        :param label:
+        :type label:
+        :param attributes:
+        :type attributes:
+        :return:
+        :rtype:
+        """
+        data = []
+        headers = []
+        content = readfile(logfile)
+        lines = Shell.find_lines_with(content, what="# csv")
+        data_attributes = lines[0].split(",")
+        index_attributes = []
+        for attribute in attributes:
+            index_attributes.append(data_attributes.index(attribute))
+        print(index_attributes)
+        headers = attributes + label
+        del lines[0]
+        for line in lines:
+            entry = line.split(",")
+            entry = [entry[i] for i in index_attributes]
+            label_tags = entry[0].split(label_split_char)
+            entry = entry + label_tags
+            data.append(entry)
+
+        return {"headers": headers,
+                "data": data}
+
+
+
+class StopWatchBlock:
+
+    def __init__(self, name, data=None, log=sys.stdout, mode="w"):
+        self.name = name
+        self.data = data
+        self.log = log
+        self.is_file = False
+        self.start = datetime.datetime.now()
+        if type(log) == str:
+            self.is_file = True
+            self.log = open(log, mode)
+
+
+    def __enter__(self):
+        StopWatch.start(self.name)
+        return StopWatch.get(self.name)
+
+    def __exit__(self, type, value, traceback):
+        self.stop = datetime.datetime.now()
+        StopWatch.stop(self.name)
+        entry = StopWatch.get(self.name)
+        if self.data:
+            print (f"# {self.name}, {entry}, {self.start}, {self.stop}, {self.data}", file=self.log)
+        else:
+            print (f"# {self.name}, {entry}, {self.start}, {self.stop}", file=self.log)
+        if self.is_file:
+            self.log.close()
+
